pub struct QueryExecutionService { /* private fields */ }Expand description
Service responsible for executing queries and managing the resulting DataView
Implementations
Sourceimpl QueryExecutionService
impl QueryExecutionService
pub fn new(case_insensitive: bool, auto_hide_empty: bool) -> Self
pub fn with_behavior_config(behavior_config: BehaviorConfig) -> Self
pub fn with_date_notation( case_insensitive: bool, auto_hide_empty: bool, date_notation: String, ) -> Self
Sourcepub fn execute(
&self,
query: &str,
current_dataview: Option<&DataView>,
original_source: Option<&DataTable>,
) -> Result<QueryExecutionResult>
pub fn execute( &self, query: &str, current_dataview: Option<&DataView>, original_source: Option<&DataTable>, ) -> Result<QueryExecutionResult>
Execute a query and return the result
This encapsulates all the query execution logic that was previously in EnhancedTui
Sourcepub fn execute_with_temp_tables(
&self,
query: &str,
current_dataview: Option<&DataView>,
original_source: Option<&DataTable>,
temp_tables: Option<&TempTableRegistry>,
) -> Result<QueryExecutionResult>
pub fn execute_with_temp_tables( &self, query: &str, current_dataview: Option<&DataView>, original_source: Option<&DataTable>, temp_tables: Option<&TempTableRegistry>, ) -> Result<QueryExecutionResult>
Execute a query with temp table support
Sourcepub fn execute_with_debug(
&self,
query: &str,
current_dataview: Option<&DataView>,
original_source: Option<&DataTable>,
debug_context: Option<DebugContext>,
) -> Result<QueryExecutionResult>
pub fn execute_with_debug( &self, query: &str, current_dataview: Option<&DataView>, original_source: Option<&DataTable>, debug_context: Option<DebugContext>, ) -> Result<QueryExecutionResult>
Execute a query with optional debug tracing
Sourcepub fn execute_with_temp_tables_and_debug(
&self,
query: &str,
current_dataview: Option<&DataView>,
original_source: Option<&DataTable>,
temp_tables: Option<&TempTableRegistry>,
debug_context: Option<DebugContext>,
) -> Result<QueryExecutionResult>
pub fn execute_with_temp_tables_and_debug( &self, query: &str, current_dataview: Option<&DataView>, original_source: Option<&DataTable>, temp_tables: Option<&TempTableRegistry>, debug_context: Option<DebugContext>, ) -> Result<QueryExecutionResult>
Execute a query with temp tables and optional debug tracing
Sourcepub fn set_case_insensitive(&mut self, case_insensitive: bool)
pub fn set_case_insensitive(&mut self, case_insensitive: bool)
Update configuration
pub fn set_auto_hide_empty(&mut self, auto_hide: bool)
pub fn set_date_notation(&mut self, date_notation: String)