pub struct QueryOrchestrator { /* private fields */ }Expand description
Orchestrates the entire query execution flow This handles all the side effects and state management around query execution
Implementations
Sourceimpl QueryOrchestrator
impl QueryOrchestrator
pub fn new(case_insensitive: bool, auto_hide_empty: bool) -> Self
pub fn with_behavior_config(behavior_config: BehaviorConfig) -> Self
Sourcepub fn execute_query(
&mut self,
query: &str,
state_container: &mut AppStateContainer,
vim_search_adapter: &RefCell<VimSearchAdapter>,
) -> Result<QueryExecutionContext>
pub fn execute_query( &mut self, query: &str, state_container: &mut AppStateContainer, vim_search_adapter: &RefCell<VimSearchAdapter>, ) -> Result<QueryExecutionContext>
Execute a query with all necessary state management
Sourcepub fn set_case_insensitive(&mut self, case_insensitive: bool)
pub fn set_case_insensitive(&mut self, case_insensitive: bool)
Update service configuration
pub fn set_auto_hide_empty(&mut self, auto_hide: bool)