Module file_readers

Module file_readers 

Structs

Grep
GREP(path, pattern [, invert]) - Read only lines matching a regex.
ReadCsv
READ_CSV(path [, delimiter]) - Read a delimited text file and emit one row per record.
ReadJson
READ_JSON(path) - Read a whole JSON document and emit one row per object.
ReadJsonl
READ_JSONL(path [, match_regex]) - Read newline-delimited JSON.
ReadStdin
READ_STDIN([match_regex]) - Read lines piped on standard input.
ReadText
READ_TEXT(path [, match_regex]) - Read a text file line by line.
ReadWords
READ_WORDS(path [, min_length [, case]]) - Read a text file and emit one row per word.