pub struct TextEditor;Expand description
Text editing utilities
Implementations
Sourceimpl TextEditor
impl TextEditor
Sourcepub fn kill_line_backward(
text: &str,
cursor_pos: usize,
) -> Option<(String, String)>
pub fn kill_line_backward( text: &str, cursor_pos: usize, ) -> Option<(String, String)>
Kill text from beginning of line to cursor position
Returns (killed_text, remaining_text)
Sourcepub fn kill_line_forward(
text: &str,
cursor_pos: usize,
) -> Option<(String, String)>
pub fn kill_line_forward( text: &str, cursor_pos: usize, ) -> Option<(String, String)>
Kill text from cursor position to end of line
Returns (killed_text, remaining_text)