Module actions
Source - ActionContext
- Context needed to determine action availability and behavior
- Action
- All possible actions that can be triggered in the UI
- ActionResult
- Result of handling an action
- CursorPosition
- Where to position the cursor when switching to Command mode
- NavigateAction
- Navigation actions with optional counts for vim-style motions
- SqlClause
- SQL clauses that can be targeted for cursor positioning
- YankTarget
- Targets for yank operations
- ActionHandler
- Trait for components that can handle actions
- can_perform_action
- Default implementation for checking action availability