pub fn handle_history_input(
ctx: &mut HistoryInputContext<'_>,
key: KeyEvent,
) -> HistoryInputResultExpand description
Handle a key event in history search mode Returns the result of processing the key event
pub fn handle_history_input(
ctx: &mut HistoryInputContext<'_>,
key: KeyEvent,
) -> HistoryInputResultHandle a key event in history search mode Returns the result of processing the key event