pub fn get_token_at_cursor(ctx: &TextNavigationContext<'_>) -> Option<String>Expand description
Get the token at the cursor position Returns the token string if found
pub fn get_token_at_cursor(ctx: &TextNavigationContext<'_>) -> Option<String>Get the token at the cursor position Returns the token string if found